==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Wplata.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Wplata extends GenericDPSObject {
    /**
     * WPLATA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * WPLATA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * WPLATA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * WPLATA.DATA_WPLATY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWplaty;

    /**
     * WPLATA.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * WPLATA.KWOTA_ZWROT
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaZwrot;

    /**
     * WPLATA.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataKsiegowania;

    /**
     * WPLATA.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WPLATA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return WPLATA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * WPLATA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return WPLATA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * WPLATA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return WPLATA.DATA_WPLATY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWplaty() {
        return dataWplaty;
    }

    /**
     * WPLATA.DATA_WPLATY
     *
     * @param dataWplaty
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWplaty(Date dataWplaty) {
        this.dataWplaty = dataWplaty;
    }

    /**
     * @return WPLATA.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * WPLATA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return WPLATA.KWOTA_ZWROT
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaZwrot() {
        return kwotaZwrot;
    }

    /**
     * WPLATA.KWOTA_ZWROT
     *
     * @param kwotaZwrot
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaZwrot(BigDecimal kwotaZwrot) {
        this.kwotaZwrot = kwotaZwrot;
    }

    /**
     * @return WPLATA.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * WPLATA.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return WPLATA.SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * WPLATA.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Wplata other = (Wplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getDataWplaty() == null ? other.getDataWplaty() == null : this.getDataWplaty().equals(other.getDataWplaty()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKwotaZwrot() == null ? other.getKwotaZwrot() == null : this.getKwotaZwrot().equals(other.getKwotaZwrot()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getDataWplaty() == null) ? 0 : getDataWplaty().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKwotaZwrot() == null) ? 0 : getKwotaZwrot().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", dataWplaty=").append(dataWplaty);
        sb.append(", kwota=").append(kwota);
        sb.append(", kwotaZwrot=").append(kwotaZwrot);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Wplata.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Wplata extends GenericDPSObject {
    /**
     * WPLATA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * WPLATA.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * WPLATA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * WPLATA.DATA_WPLATY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWplaty;

    /**
     * WPLATA.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * WPLATA.KWOTA_ZWROT
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaZwrot;

    /**
     * WPLATA.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataKsiegowania;

    /**
     * WPLATA.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WPLATA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * WPLATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return WPLATA.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * WPLATA.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return WPLATA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * WPLATA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return WPLATA.DATA_WPLATY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWplaty() {
        return dataWplaty;
    }

    /**
     * WPLATA.DATA_WPLATY
     *
     * @param dataWplaty
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWplaty(Date dataWplaty) {
        this.dataWplaty = dataWplaty;
    }

    /**
     * @return WPLATA.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * WPLATA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return WPLATA.KWOTA_ZWROT
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaZwrot() {
        return kwotaZwrot;
    }

    /**
     * WPLATA.KWOTA_ZWROT
     *
     * @param kwotaZwrot
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaZwrot(BigDecimal kwotaZwrot) {
        this.kwotaZwrot = kwotaZwrot;
    }

    /**
     * @return WPLATA.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * WPLATA.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return WPLATA.SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * WPLATA.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Wplata other = (Wplata) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getDataWplaty() == null ? other.getDataWplaty() == null : this.getDataWplaty().equals(other.getDataWplaty()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKwotaZwrot() == null ? other.getKwotaZwrot() == null : this.getKwotaZwrot().equals(other.getKwotaZwrot()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getDataWplaty() == null) ? 0 : getDataWplaty().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKwotaZwrot() == null) ? 0 : getKwotaZwrot().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", dataWplaty=").append(dataWplaty);
        sb.append(", kwota=").append(kwota);
        sb.append(", kwotaZwrot=").append(kwotaZwrot);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}
